#!/bin/bash
#
# Script:	SDE.sh
# Author:	Matias Lacasia
# Purpose:      Provides a disk space saving utility 
#               that removes any *.o and *.class file under the chosen directory, SDE also
#               compresses any files not accesed in the chosen time to tar.gz format.
#
#		If there are no arguments, SDE will work on the current working directory and minium  
#		access time will be set to 1 minute.
#		If there is only one argument, it has to be the directory to run SDE on, minium
#		access time will be set to 1 minute.
#		If there are two arguments, SDE will work with the directory indicated in the first 
#		argument and the time set in the second one.
#
# Usage:	SDE.sh [DIRECTORY] [TIME]



if [ -z $1 ]
then
	DIR=$PWD
	N=1
elif [ -n $1 ] && [ -z $2 ]
then
	DIR=$1
	N=1
else
	DIR=$1
	N=$2
fi

if [ ! -d $DIR ]
then
	echo "$DIR does not exist!"
	exit 1
else
	echo "Running SDE on $DIR and it's subdirectories"
fi


find $DIR -name "*.o" -exec rm {} +
find $DIR -name "*.class" -exec rm {} +
find $DIR -amin +$N -type f -execdir tar -cvzf {}.tar.gz {} --remove-files \;
