#!/bin/bash
#
# Script:	delete.sh
# Author:	Kieren Jamieson 
# Purpose:      Provides a safe alternative to "rm" as 
#               each file is moved to a "trashcan" folder and kept for a mimimum of 3 days (or next reboot)
#               before it is deleted.
#
#		Files are "cleaned" each time delete is run (a check is made if they are over
#		three days old).  Files are stored by their original name plus a date/time stamp
#
#               Usage:	delete.sh [file1] [file2] ... [filen]

JUNKDIR="/tmp/trashcan.$LOGNAME"
DATE=`date +%Y-%m-%d_%H%M%S`

if [ ! -d $JUNKDIR ]
then
  echo "$JUNKDIR does not exist, creating..."
  mkdir -p $JUNKDIR
  if [ $? -ne 0 ]
  then
    echo "Error making directory $JUNKDIR - file not deleted"
    exit 1
  fi
  chmod 755 $JUNKDIR
fi
for file in $*
do
 newfile=`basename $file`
 if [ -r $file ]
 then
   mv $file $JUNKDIR/${newfile}.$DATE
 else
   echo "$file does not exist!"
 fi
done
# Now check for cleanup

find $JUNKDIR -mtime +3 -exec rm {} \;
